module UU
  module OS
    module Util

      # Module providing methods for loading version of project.
      # @private
      module VersionLoader # :nodoc:

        # Returns version from given version file.
        # @param [String] version_file_path Path to version file
        # @return [String, nil] Version or +nil+ if version file
        #    does not exist or does not contain version constant.
        def get_version(version_file_path)
          return VersionLoader.get_version(version_file_path)
        end

        # @see #get_version
        # @private
        def self.get_version(version_file_path) # :nodoc:
          return nil if !File.exists?(version_file_path)
          content = File.read(version_file_path)
          if content =~ /VERSION[ ]*=[ ]*['"]([^'"]+)['"]/
            return $1
          else
            return nil
          end
        end

      end

    end
  end
end
